pub struct DarkPageContext {Show 14 fields
pub page_title: String,
pub site_title: String,
pub content: String,
pub nav_items: Vec<NavItem>,
pub sidebar_groups: Vec<SidebarGroup>,
pub current_path: String,
pub has_footer: bool,
pub has_footer_message: bool,
pub footer_message: String,
pub has_footer_copyright: bool,
pub footer_copyright: String,
pub current_lang: String,
pub available_locales: Vec<LocaleInfo>,
pub root_path: String,
}Expand description
暗色主题页面模板上下文
Fields
page_title: Stringsite_title: Stringcontent: Stringcurrent_path: Stringcurrent_lang: Stringavailable_locales: Vec<LocaleInfo>root_path: StringTrait Implementations
Sourceimpl Clone for DarkPageContext
impl Clone for DarkPageContext
Sourcefn clone(&self) -> DarkPageContext
fn clone(&self) -> DarkPageContext
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DarkPageContext
impl Debug for DarkPageContext
Sourceimpl Display for DarkPageContext
impl Display for DarkPageContext
Sourceimpl From<&PageContext> for DarkPageContext
impl From<&PageContext> for DarkPageContext
Sourcefn from(context: &PageContext) -> Self
fn from(context: &PageContext) -> Self
Converts to this type from the input type.
Sourceimpl Template for DarkPageContext
impl Template for DarkPageContext
Sourceconst SIZE_HINT: usize = 6669
const SIZE_HINT: usize = 6669
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourceconst MIME_TYPE: &'static str = "text/html; charset=utf-8"
const MIME_TYPE: &'static str = "text/html; charset=utf-8"
The MIME type (Content-Type) of the data that gets rendered by this Template
Sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt bufferAuto Trait Implementations
impl Freeze for DarkPageContext
impl RefUnwindSafe for DarkPageContext
impl Send for DarkPageContext
impl Sync for DarkPageContext
impl Unpin for DarkPageContext
impl UnsafeUnpin for DarkPageContext
impl UnwindSafe for DarkPageContext